@@ -1,8 +1,12 @@
 import asyncio
 import logging
 import time
+import socket
+import errno
 from typing import Optional
+from ws4py import exc
 from ws4py.client.threadedclient import WebSocketClient
+from ws4py.websocket import pyOpenSSLError
 
 from .rustplus_pb2 import AppMessage, AppRequest
 from ..structures import RustChatMessage
@@ -33,12 +37,15 @@ class RustWsClient(WebSocketClient):
 
     def connect(self) -> None:
 
-        try:
-            super().connect()
-            self.client_terminated = False
-            self.server_terminated = False
-        except OSError:
-            raise ConnectionRefusedError()
+        while True:
+            try:
+                super().connect()
+                self.client_terminated = False
+                self.server_terminated = False
+                break
+            except:
+                logging.getLogger("rustplus.py").warn("Cannot Connect to server. Retrying in 10")
+                time.sleep(10)
 
     def close(self, code=1000, reason='') -> None:
         super().close(code=code, reason=reason)
@@ -104,7 +111,8 @@ class RustWsClient(WebSocketClient):
         try:
             self.send(raw_data, binary=True)
         except:
-            raise ClientNotConnectedError("Not Connected")
+            self.connect()
+            self._retry_failed_request(app_request=request)
 
     async def _retry_failed_request(self, app_request : AppRequest):
         """
@@ -180,3 +188,39 @@ class RustWsClient(WebSocketClient):
             raise RequestError(response.response.error.error)
 
         return response
+
+    def once(self):
+
+        if self.terminated:
+            logging.getLogger("ws4py").debug("WebSocket is already terminated")
+            return False
+        try:
+            b = b''
+            if self._is_secure:
+                b = self._get_from_pending()
+            if not b and not self.buf:
+                try:
+                    b = self.sock.recv(self.reading_buffer_size)
+                except OSError:
+                    self.connect()
+                    return True
+            if not b and not self.buf:
+                return False
+            self.buf += b
+        except (socket.error, OSError, pyOpenSSLError) as e:
+            if hasattr(e, "errno") and e.errno == errno.EINTR:
+                pass
+            else:
+                self.unhandled_error(e)
+                return False
+        else:
+            # process as much as we can
+            # the process will stop either if there is no buffer left
+            # or if the stream is closed
+            # only pass the requested number of bytes, leave the rest in the buffer
+            requested = self.reading_buffer_size
+            if not self.process(self.buf[:requested]):
+                return False
+            self.buf = self.buf[requested:]
+
+        return True
